@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: texmath
-version: 0.8.4.2
-id: texmath-0.8.4.2-d95aec46ca55bfe78645f4742c3c4ff8
-key: texma_0zUTTZ1n9zd4QlkHKOl9SZ
+version: 0.8.5
+id: texmath-0.8.5-aa2be80ae996b0529501af10b92dc849
+key: texma_FyPTjXvMZR98NW4jnt0fcT
 license: GPL
 maintainer: jgm@berkeley.edu
 stability: Experimental
@@ -54,20 +54,20 @@ exposed-modules:
     Text.TeXMath.Unicode.ToUnicode Text.TeXMath.Unicode.ToTeX
     Text.TeXMath.Unicode.ToASCII
 hidden-modules: Text.TeXMath.Compat Text.TeXMath.Shared
-                Text.TeXMath.TeX
+                Text.TeXMath.TeX Paths_texmath
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.4.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.4.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.4.2
-hs-libraries: HStexmath-0.8.4.2-0zUTTZ1n9zd4QlkHKOl9SZ
+import-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.5
+library-dirs: /usr/lib/ghc-7.10.3/site-local/texmath-0.8.5
+data-dir: /usr/share/arm-linux-ghc-7.10.3/texmath-0.8.5
+hs-libraries: HStexmath-0.8.5-FyPTjXvMZR98NW4jnt0fcT
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    pandoc-types-1.16.1-4cd1533070797f7596c108f3982c26c4
-    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
+    pandoc-types-1.16.1-0b1608b10c9621b9412cccf92ea53ad6
+    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    xml-1.3.14-47d6d03c8a900e03cf8951206101564b
+    xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
 haddock-interfaces: /usr/share/doc/haskell-texmath/html/texmath.haddock
 haddock-html: /usr/share/doc/haskell-texmath/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
